pub enum UserError {
Show 13 variants
InactiveStreamId,
UnexpectedFrameType,
PayloadTooBig,
Rejected,
ReleaseCapacityTooBig,
OverflowedStreamId,
MalformedHeaders,
MissingUriSchemeAndAuthority,
PollResetAfterSendResponse,
SendPingWhilePending,
SendSettingsWhilePending,
PeerDisabledServerPush,
InvalidInformationalStatusCode,
}Expand description
Errors caused by users of the library
Variants
InactiveStreamId
The stream ID is no longer accepting frames.
UnexpectedFrameType
The stream is not currently expecting a frame of this type.
PayloadTooBig
The payload size is too big
Rejected
The application attempted to initiate too many streams to remote.
ReleaseCapacityTooBig
The released capacity is larger than claimed capacity.
OverflowedStreamId
The stream ID space is overflowed.
A new connection is needed.
MalformedHeaders
Illegal headers, such as connection-specific headers.
MissingUriSchemeAndAuthority
Request submitted with relative URI.
PollResetAfterSendResponse
Calls SendResponse::poll_reset after having called send_response.
SendPingWhilePending
Calls PingPong::send_ping before receiving a pong.
SendSettingsWhilePending
Tries to update local SETTINGS while ACK has not been received.
PeerDisabledServerPush
Tries to send push promise to peer who has disabled server push
InvalidInformationalStatusCode
Invalid status code for informational response (must be 1xx)